#include "rheolef/tensor4.h"
using namespace std;
using namespace rheolef;
int main (int argc, char**argv) {
  tensor4 a; 
  for (size_t i = 0; i < 3; i++) for (size_t j = 0; j < 3; j++){
      for (size_t k = 0; k < 3; k++) for (size_t l = 0; l < 3; l++){
          a(i,j,k,l) = 1;
      }
  }
  tensor4 b = a;
  cout << "b(0,0,0,0) = " << b(1,0,2,0) << endl;  
  tensor4 c;
  cout << "c(0,0,0,0) = " << c(0,0,2,0) << endl;  
  for (size_t i = 0; i < 3; i++) for (size_t j = 0; j < 3; j++){
      for (size_t k = 0; k < 3; k++) for (size_t l = 0; l < 3; l++){
          c(i,j,k,l) = i+j+k+l;
      }
  }
  cout << "le tenseur c  = "   << endl;  
  for (size_t i = 0; i < 3; i++) for (size_t j = 0; j < 3; j++){
      for (size_t k = 0; k < 3; k++) for (size_t l = 0; l < 3; l++){
	  cout  << " " << c(i,j,k,l) ;  
         
      }
      cout << endl; 
  }
}
